
********************************************************************************
/*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~*/
/*------- Econ 338 - Conference 2-- Stata Presentation Winter 2021-------------*/
/*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~*/
********************************************************************************

clear all
set more off

*cap log close


/*****************************************************************

   1. Organize the workplace.

*****************************************************************/

*****  Way3 : set the path

global path "C:\Users\yaya1\Dropbox\Fall2020\ECON338\Stata Conference\Conference2"
*global DATA "\Original_Data"
*global data_conf "\Conf2_data"



/*****************************************************************

   2. Prepare your data
   - Create categorial variable (age group)
   - Variable and value labels
   
*****************************************************************/

**** Open the data
use "$path\Original_Data\data_presentation.dta"

*** Select sample: individuals aged 20-60
keep if inrange(age,20,60)
*** 

** Create Age group variable 
gen age_g =1 if age>=20 & age<=24
replace age_g=2 if age>=25 & age<=29
replace age_g=3 if age>=30 & age<=34
replace age_g=4 if age>=35 & age<=39
replace age_g=5 if age>=40 & age<=44
replace age_g=6 if age>=45 & age<=49
replace age_g=7 if age>=50 & age<=54
replace age_g=8 if age>=55 & age<=60

**Tabulate to see 
tab age_g

** Label variable
label var age_g "Age group"

**Label values
label define age_label 1 "20-24", modify
label define age_label 2 "25-29", modify
label define age_label 3 "30-34", modify
label define age_label 4 "35-39", modify
label define age_label 5 "40-44", modify
label define age_label 6 "45-49", modify
label define age_label 7 "50-54", modify
label define age_label 8 "55-60", modify
label values age_g age_label

*Generate new variables (remember that we should label them too)
gen age2=age^2

**Rename variables

rename incfam07on inc_quintiles
rename hlth health

*** Create quintiles

gen young_inc=.
replace young_inc=1 if inc_quintiles==0 & age<=30
replace young_inc=2 if inc_quintiles==1 & age<=30
replace young_inc=3 if inc_quintiles==2 & age<=30
replace young_inc=4 if inc_quintiles==3 & age<=30
replace young_inc=5 if inc_quintiles==4 & age<=30

*way 1: Modify uninsured as a dummy taking 0 and 1

tab uninsured, gen(uninsured)

rename uninsured2 covered 
label define covered_l 0 "No", modify
label define covered_l 1 "Yes", modify
label values covered covered_l

rename uninsured1 not_covered
label define not_covered_l 0 "No", modify
label define not_covered_l 1 "Yes", modify
label values not_covered not_covered_l

**** Save as a new data in a new folder
save "$path\Intermediate_data\data_regressions.dta",replace


/*****************************************************************

   2. Graphs
   
*****************************************************************/

*** Histogram

hist health if covered==1, discrete title("Insured")  
graph export "$path\Graphs\hhealthhi.pdf", as(pdf) replace

*** Bar plot

graph bar health, over(sex) over(covered) title("Covered ? Yes or No")  
graph export "$path\Graphs\health_sex.pdf", as(pdf) replace


/*****************************************************************

   3. OLS regressions and saved output

*****************************************************************/

****   3.1 Run OLS

** 3.1  The regress command
help regress 

*** Regression 1
regress health covered 

*** Regression 2
reg health covered yedu inc famsize age

*** Regression 3, Add options
reg health covered yedu inc famsize age,noconstant

*** 3.2  Define y and X  and 

global independent "health"
global  main_dependent "covered"
global  second_dependent "yedu inc famsize age"

*** Regression 1
reg $independent $main_dependent 

*** Regression 2
reg $independent $main_dependent $second_dependent

** 3.3 Arrange regression, summary, and tabulation into an illustrative table
help outreg2 

** Regress and store 
reg $independent $main_dependent
est store reg1

reg $independent $main_dependent $second_dependent
est store reg2

outreg2 [reg1 reg2] using  "$path\Results\OLS_results.xls", excel replace 

outreg2 [reg1 reg2] using  "$path\Results\OLS_results.xls", word replace 

*** 3.2  Export tables
table age sex

outreg2 age sex using "$path\Results\table_2ways.xls", replace cross side 





